SettingsLocalDataSourceImpl class

Implemented types

Constructors

SettingsLocalDataSourceImpl({required SharedPreferences sharedPreferences})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences → SharedPreferences
final

Methods

getSettings() Future<SettingsModel>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveSettings(Settings settings) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited