StockApiDataSourceImpl class
- Implemented types
Constructors
- StockApiDataSourceImpl({required Client client})
Properties
- client → Client
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDailyPriceList(
String ticker, int days) → Future< List< double> > -
override
-
getStockList(
List< String> tickers) → Future<List< StockModel> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited