SettingsModel class

Inheritance

Constructors

SettingsModel({required List<String> watchList, required int rsiPeriod, required double rsiSellThreshold, required double rsiBuyThreshold, required int rotationPeriod, bool isDarkMode = false})
const
SettingsModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isDarkMode bool
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rotationPeriod int
finalinherited
rsiBuyThreshold double
finalinherited
rsiPeriod int
finalinherited
rsiSellThreshold double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
watchList List<String>
finalinherited

Methods

copyWith({List<String>? watchList, int? rsiPeriod, double? rsiBuyThreshold, double? rsiSellThreshold, int? rotationPeriod}) Settings
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited