StockModel class

Inheritance

Constructors

StockModel({required String ticker, required String name, required double currentPrice, double? previousClose, double? change, double? changeInPercent, required DateTime lastUpdated, double? rsi})
const
StockModel.fromYahooJson(Map<String, dynamic> json)
factory

Properties

change double?
finalinherited
changeInPercent double?
finalinherited
currentPrice double
finalinherited
hashCode int
The hash code for this object.
no setterinherited
lastUpdated DateTime
finalinherited
name String
finalinherited
previousClose double?
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rsi double?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
ticker String
finalinherited

Methods

copyWith({String? ticker, String? name, double? currentPrice, double? previousClose, double? change, double? changeInPercent, DateTime? lastUpdated, double? rsi}) Stock
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited