Settings class

Implementers
Annotations

Constructors

Settings({required List<String> watchList, required int rsiPeriod, required double rsiBuyThreshold, required double rsiSellThreshold, required int rotationPeriod, bool isDarkMode = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDarkMode bool
final
rotationPeriod int
final
rsiBuyThreshold double
final
rsiPeriod int
final
rsiSellThreshold double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
watchList List<String>
final

Methods

copyWith({List<String>? watchList, int? rsiPeriod, double? rsiBuyThreshold, double? rsiSellThreshold, int? rotationPeriod}) Settings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited