SettingsNotifier class

Inheritance

Constructors

SettingsNotifier({required GetSettingsUseCase getSettingsUseCase, required SaveSettingsUseCase saveSettingsUseCase})

Properties

debugState SettingsState
A development-only way to access state outside of StateNotifier.
no setterinherited
getSettingsUseCase GetSettingsUseCase
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
If a listener has been added using addListener and hasn't been removed yet.
no setterinherited
mounted bool
Whether dispose was called or not.
no setterinherited
onError ↔ ErrorListener?
A callback for error reporting if one of the listeners added with addListener throws.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveSettingsUseCase SaveSettingsUseCase
final
state SettingsState
The current "state" of this StateNotifier.
getter/setter pairinherited
stream Stream<SettingsState>
A broadcast stream representation of a StateNotifier.
no setterinherited

Methods

addListener(Listener<SettingsState> listener, {bool fireImmediately = true}) → RemoveListener
Subscribes to this object.
inherited
dispose() → void
Frees all the resources associated with this object.
inherited
loadSettings() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveSettings(Settings settings) Future<void>
toString() String
A string representation of this object.
inherited
updateShouldNotify(SettingsState old, SettingsState current) bool
Whether to notify listeners or not when state changes
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited