Stock class
- Implementers
- Annotations
Constructors
Properties
- change → double?
-
final
- changeInPercent → double?
-
final
- currentPrice → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUpdated → DateTime
-
final
- name → String
-
final
- previousClose → double?
-
final
- rsi → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticker → String
-
final
Methods
-
copyWith(
{String? ticker, String? name, double? currentPrice, double? previousClose, double? change, double? changeInPercent, DateTime? lastUpdated, double? rsi}) → Stock -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited